"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var color_1 = require("tns-core-modules/color");
var image_source_1 = require("tns-core-modules/image-source");
var ColorHelper_1 = require("./ColorHelper");
function createSVGMatrix() {
    return new TNSDOMMatrix(Canvas.createSVGMatrix());
}
exports.createSVGMatrix = createSVGMatrix;
var TNSCanvas = (function (_super) {
    __extends(TNSCanvas, _super);
    function TNSCanvas() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.useMetal = false;
        return _this;
    }
    TNSCanvas.prototype.createNativeView = function () {
        return Canvas.alloc().initWithFrameUseGL(CGRectZero, !this.useMetal);
    };
    TNSCanvas.prototype.getContext = function (type) {
        if (type && type === '2d') {
            if (!this._2dContext) {
                this._2dContext = new TNSCanvasRenderingContext2D(this.nativeView.getContextWithType(type));
            }
        }
        return this._2dContext;
    };
    TNSCanvas.prototype.getBoundingClientRect = function () {
        var view = this;
        var frame = view.ios.frame;
        var width = view.getMeasuredWidth();
        var height = view.getMeasuredHeight();
        return {
            bottom: height,
            height: height,
            left: frame.origin.x,
            right: width,
            top: frame.origin.y,
            width: width,
            x: frame.origin.x,
            y: frame.origin.y
        };
    };
    return TNSCanvas;
}(canvas_plugin_common_1.TNSCanvasBase));
exports.TNSCanvas = TNSCanvas;
var ImageData = (function (_super) {
    __extends(ImageData, _super);
    function ImageData(nativeInstance) {
        var _this = _super.call(this, nativeInstance) || this;
        var buffer = interop.bufferFromData(nativeInstance.data);
        _this.data = new Uint8ClampedArray(buffer, 0, buffer.byteLength);
        return _this;
    }
    return ImageData;
}(canvas_plugin_common_1.ImageDataBase));
exports.ImageData = ImageData;
var TNSCanvasRenderingContext2D = (function (_super) {
    __extends(TNSCanvasRenderingContext2D, _super);
    function TNSCanvasRenderingContext2D(context) {
        var _this = _super.call(this) || this;
        _this.context = context;
        return _this;
    }
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowColor", {
        set: function (color) {
            this.context.shadowColor = new color_1.Color(color).ios;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalAlpha", {
        set: function (alpha) {
            this.context.globalAlpha = alpha;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingEnabled", {
        set: function (enabled) {
            this.context.imageSmoothingEnabled = enabled;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingQuality", {
        set: function (quality) {
            switch (quality) {
                case 'high':
                    this.context.imageSmoothingQuality = 2;
                    break;
                case 'medium':
                    this.context.imageSmoothingQuality = 1;
                    break;
                default:
                    this.context.imageSmoothingQuality = 0;
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineDashOffset", {
        set: function (offset) {
            this.context.lineDashOffset = offset;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineJoin", {
        set: function (join) {
            switch (join) {
                case 'bevel':
                    this.context.lineJoin = 0;
                    break;
                case 'round':
                    this.context.lineJoin = 1;
                    break;
                default:
                    this.context.lineJoin = 2;
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineCap", {
        set: function (cap) {
            switch (cap) {
                case 'round':
                    this.context.lineCap = 1;
                    break;
                case 'square':
                    this.context.lineCap = 2;
                    break;
                default:
                    this.context.lineCap = 0;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "miterLimit", {
        set: function (limit) {
            this.context.miterLimit = limit;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowBlur", {
        set: function (blur) {
            this.context.shadowBlur = blur;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetX", {
        set: function (x) {
            this.context.shadowOffsetX = x;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetY", {
        set: function (y) {
            this.context.shadowOffsetY = y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "textAlign", {
        set: function (alignment) {
            switch (alignment) {
                case 'start':
                    this.context.textAlign = 1;
                    break;
                case 'center':
                    this.context.textAlign = 2;
                    break;
                case 'end':
                    this.context.textAlign = 3;
                    break;
                case 'right':
                    this.context.textAlign = 4;
                    break;
                default:
                    this.context.textAlign = 0;
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalCompositeOperation", {
        set: function (composite) {
            switch (composite.toLowerCase()) {
                case 'source-over':
                    this.context.globalCompositeOperation = 0;
                    break;
                case 'source-in':
                    this.context.globalCompositeOperation = 1;
                    break;
                case 'source-out':
                    this.context.globalCompositeOperation = 2;
                    break;
                case 'source-atop':
                    this.context.globalCompositeOperation = 3;
                    break;
                case 'destination-over':
                    this.context.globalCompositeOperation = 4;
                    break;
                case 'destination-in':
                    this.context.globalCompositeOperation = 5;
                    break;
                case 'destination-out':
                    this.context.globalCompositeOperation = 6;
                    break;
                case 'destination-atop':
                    this.context.globalCompositeOperation = 7;
                    break;
                case 'lighter':
                    this.context.globalCompositeOperation = 8;
                    break;
                case 'copy':
                    this.context.globalCompositeOperation = 9;
                    break;
                case 'xor':
                    this.context.globalCompositeOperation = 10;
                    break;
                case 'multiply':
                    this.context.globalCompositeOperation = 11;
                    break;
                case 'screen':
                    this.context.globalCompositeOperation = 12;
                    break;
                case 'overlay':
                    this.context.globalCompositeOperation = 13;
                    break;
                case 'darken':
                    this.context.globalCompositeOperation = 14;
                    break;
                case 'lighten':
                    this.context.globalCompositeOperation = 15;
                    break;
                case 'color-dodge':
                    this.context.globalCompositeOperation = 16;
                    break;
                case 'color-burn':
                    this.context.globalCompositeOperation = 17;
                    break;
                case 'hard-light':
                    this.context.globalCompositeOperation = 18;
                    break;
                case 'soft-light':
                    this.context.globalCompositeOperation = 19;
                    break;
                case 'difference':
                    this.context.globalCompositeOperation = 20;
                    break;
                case 'exclusion':
                    this.context.globalCompositeOperation = 21;
                    break;
                case 'hue':
                    this.context.globalCompositeOperation = 22;
                    break;
                case 'saturation':
                    this.context.globalCompositeOperation = 22;
                    break;
                case 'color':
                    this.context.globalCompositeOperation = 23;
                    break;
                case 'luminosity':
                    this.context.globalCompositeOperation = 25;
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "fillStyle", {
        set: function (color) {
            var nativeStyle;
            if (color instanceof CanvasGradient) {
                nativeStyle = color.native;
            }
            else {
                var wasHsl = false;
                if (color.startsWith('hsla')) {
                    wasHsl = true;
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (color.startsWith('hsl')) {
                    wasHsl = true;
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' && color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                nativeStyle = Color.alloc().initWithColor(new color_1.Color(color).ios);
            }
            this.context.fillStyle = nativeStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "strokeStyle", {
        set: function (color) {
            var nativeStyle;
            if (color instanceof CanvasGradient) {
                nativeStyle = color.native;
            }
            else {
                if (color.startsWith('hsla')) {
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (color.startsWith('hsl')) {
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' && color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                nativeStyle = Color.alloc().initWithColor(new color_1.Color(color).ios);
            }
            this.context.strokeStyle = nativeStyle;
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvasRenderingContext2D.prototype.addHitRegion = function (region) {
    };
    TNSCanvasRenderingContext2D.prototype.arc = function (x, y, radius, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.context.arcWithXYRadiusStartAngleEndAngleAnticlockwise(x, y, radius, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        this.context.arcToX1Y1X2Y2Radius(x1, y1, x2, y2, radius);
    };
    TNSCanvasRenderingContext2D.prototype.beginPath = function () {
        this.context.beginPath();
    };
    TNSCanvasRenderingContext2D.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        this.context.bezierCurveToCp1xCp1yCp2xCp2yXY(cp1x, cp1y, cp2x, cp2y, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.clearHitRegions = function () {
    };
    TNSCanvasRenderingContext2D.prototype.clearRect = function (x, y, width, height) {
        this.context.clearRectWithXYWidthHeight(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.clip = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (typeof args[0] === 'string') {
            this.context.clipWithRule(args[0]);
        }
        else if (args[0] instanceof TNSPath2D && typeof args[1] === 'string') {
            this.context.clipWithPathRule(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D) {
            this.context.clipWithPath(args[0].native);
        }
        else {
            this.context.clip();
        }
    };
    TNSCanvasRenderingContext2D.prototype.closePath = function () {
        this.context.closePath();
    };
    TNSCanvasRenderingContext2D.prototype.createImageData = function (width, height) {
        if (width instanceof ImageData) {
            return new ImageData(this.context.createImageDataWithImageData(width.native));
        }
        else {
            return new ImageData(this.context.createImageDataWithWidthHeight(width, height));
        }
    };
    TNSCanvasRenderingContext2D.prototype.createLinearGradient = function (x0, y0, x1, y1) {
        return CanvasGradient.fromNative(this.context.createLinearGradientWithX0Y0X1Y1(x0, y0, x1, y1));
    };
    TNSCanvasRenderingContext2D.prototype.createPattern = function (image, repetition) {
    };
    TNSCanvasRenderingContext2D.prototype.createRadialGradient = function (x0, y0, r0, x1, y1, r1) {
        return CanvasGradient.fromNative(this.context.createRadialGradientWithX0Y0R0X1Y1R1(x0, y0, r0, x1, y1, r1));
    };
    TNSCanvasRenderingContext2D.prototype.drawFocusIfNeeded = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
    };
    TNSCanvasRenderingContext2D.prototype.drawImage = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (!args) {
            return;
        }
        var image = args[0];
        if (image instanceof image_source_1.ImageSource) {
            image = image.ios;
        }
        if (args.length === 3) {
            this.context.drawImageWithImageDxDy(image, args[1], args[2]);
        }
        else if (args.length === 5) {
            this.context.drawImageWithImageDxDyDWidthDHeight(image, args[1], args[2], args[3], args[4]);
        }
        else if (args.length === 9) {
            this.context.drawImageWithImageSxSySWidthSHeightDxDyDWidthDHeight(image, args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8]);
        }
    };
    TNSCanvasRenderingContext2D.prototype.ellipse = function (x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.context.ellipseWithXYRadiusXRadiusYRotationStartAngleEndAngleAnticlockwise(x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.fill = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (typeof args[0] === 'string') {
            this.context.fillWithRule(args[0]);
        }
        else if (args[0] instanceof TNSPath2D && typeof args[1] === 'string') {
            this.context.fillWithPathRule(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D && typeof args[1] === 'string') {
            this.context.fillWithPath(args[0].native);
        }
        else {
            this.context.fill();
        }
    };
    TNSCanvasRenderingContext2D.prototype.fillRect = function (x, y, width, height) {
        this.context.fillRectWithXYWidthHeight(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.fillText = function (text, x, y, maxWidth) {
        this.context.fillTextWithTextXYWidth(text, x, y, maxWidth);
    };
    TNSCanvasRenderingContext2D.prototype.getImageData = function (sx, sy, sw, sh) {
        return new ImageData(this.context.getImageDataWithSxSySwSh(sx, sy, sw, sh));
    };
    TNSCanvasRenderingContext2D.prototype.getLineDash = function () {
        return this.context.getLineDash();
    };
    TNSCanvasRenderingContext2D.prototype.isPointInPath = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.isPointInStroke = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.lineTo = function (x, y) {
        this.context.lineToXY(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.measureText = function (text) {
        return new TextMetrics(this.context.measureTextWithText(text));
    };
    TNSCanvasRenderingContext2D.prototype.moveTo = function (x, y) {
        this.context.moveToXY(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.putImageData = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (!args) {
            return;
        }
        var data = args[0];
        if (args.length === 3) {
            this.context.putImageDataWithImageDataDxDy(data.native, args[1], args[2]);
        }
        else if (args.length === 7) {
            this.context.putImageDataWithImageDataDxDyDirtyXDirtyYDirtyWidthDirtyHeight(data.native, args[1], args[2], args[3], args[4], args[5], args[6]);
        }
    };
    TNSCanvasRenderingContext2D.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        this.context.quadraticCurveToCpxCpyXY(cpx, cpy, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.rect = function (x, y, width, height) {
        this.context.rectWithXYWidthHeight(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.removeHitRegion = function (id) {
    };
    TNSCanvasRenderingContext2D.prototype.resetTransform = function () {
        this.context.resetTransform();
    };
    TNSCanvasRenderingContext2D.prototype.restore = function () {
        this.context.restore();
    };
    TNSCanvasRenderingContext2D.prototype.rotate = function (angle) {
        this.context.rotateWithAngle(angle);
    };
    TNSCanvasRenderingContext2D.prototype.save = function () {
        this.context.save();
    };
    TNSCanvasRenderingContext2D.prototype.scale = function (x, y) {
        this.context.scaleWithXY(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.scrollPathIntoView = function (path) {
    };
    TNSCanvasRenderingContext2D.prototype.setLineDash = function (segments) {
        this.context.setLineDashWithSegments(segments);
    };
    TNSCanvasRenderingContext2D.prototype.setTransform = function (a, b, c, d, e, f) {
        this.context.setTransformWithABCDEF(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.stroke = function (path) {
        if (path) {
            this.context.strokeWithPath(path.native);
        }
        else {
            this.context.stroke();
        }
    };
    TNSCanvasRenderingContext2D.prototype.strokeRect = function (x, y, width, height) {
        this.context.strokeRectWithXYWidthHeight(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.strokeText = function (text, x, y, maxWidth) {
        this.context.strokeTextWithTextXYWidth(text, x, y, maxWidth);
    };
    TNSCanvasRenderingContext2D.prototype.transform = function (a, b, c, d, e, f) {
        this.context.transformWithABCDEF(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.translate = function (x, y) {
        this.context.translateWithXY(x, y);
    };
    return TNSCanvasRenderingContext2D;
}(canvas_plugin_common_1.TNSCanvasRenderingContext2DBase));
exports.TNSCanvasRenderingContext2D = TNSCanvasRenderingContext2D;
var TextMetrics = (function (_super) {
    __extends(TextMetrics, _super);
    function TextMetrics(instance) {
        return _super.call(this, instance) || this;
    }
    Object.defineProperty(TextMetrics.prototype, "width", {
        get: function () {
            return this.nativeInstance.width;
        },
        enumerable: true,
        configurable: true
    });
    return TextMetrics;
}(canvas_plugin_common_1.TextMetricsBase));
exports.TextMetrics = TextMetrics;
var TNSPath2D = (function (_super) {
    __extends(TNSPath2D, _super);
    function TNSPath2D(instance) {
        return _super.call(this, instance) || this;
    }
    TNSPath2D.prototype.addPath = function (path, transform) {
        if (transform) {
            this.nativeInstance.addPathWithPathTransform(path.nativeInstance, transform.native);
        }
        else {
            this.nativeInstance.addPathWithPath(path.nativeInstance);
        }
    };
    TNSPath2D.prototype.arc = function (x, y, radius, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.nativeInstance.arcWithXYRadiusStartAngleEndAngleAnticlockwise(x, y, radius, startAngle, endAngle, anticlockwise);
    };
    TNSPath2D.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        this.nativeInstance.arcToX1Y1X2Y2Radius(x1, y1, x2, y2, radius);
    };
    TNSPath2D.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        this.nativeInstance.bezierCurveToCp1xCp1yCp2xCp2yXY(cp1x, cp1y, cp2x, cp2y, x, y);
    };
    TNSPath2D.prototype.closePath = function () {
        this.nativeInstance.closePath();
    };
    TNSPath2D.prototype.ellipse = function (x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.nativeInstance.ellipseWithXYRadiusXRadiusYRotationStartAngleEndAngleAnticlockwise(x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
    };
    TNSPath2D.prototype.lineTo = function (x, y) {
        this.nativeInstance.lineToXY(x, y);
    };
    TNSPath2D.prototype.moveTo = function (x, y) {
        this.nativeInstance.moveToXY(x, y);
    };
    TNSPath2D.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        this.nativeInstance.quadraticCurveToCpxCpyXY(cpx, cpy, x, y);
    };
    TNSPath2D.prototype.rect = function (x, y, width, height) {
        this.nativeInstance.rectWithXYWidthHeight(x, y, width, height);
    };
    return TNSPath2D;
}(canvas_plugin_common_1.TNSPath2DBase));
exports.TNSPath2D = TNSPath2D;
var TNSDOMMatrix = (function (_super) {
    __extends(TNSDOMMatrix, _super);
    function TNSDOMMatrix(instance) {
        return _super.call(this, instance) || this;
    }
    Object.defineProperty(TNSDOMMatrix.prototype, "a", {
        get: function () {
            return this.nativeInstance.a;
        },
        set: function (value) {
            this.nativeInstance.a = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSDOMMatrix.prototype, "b", {
        get: function () {
            return this.nativeInstance.b;
        },
        set: function (value) {
            this.nativeInstance.b = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSDOMMatrix.prototype, "c", {
        get: function () {
            return this.nativeInstance.c;
        },
        set: function (value) {
            this.nativeInstance.c = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSDOMMatrix.prototype, "d", {
        get: function () {
            return this.nativeInstance.d;
        },
        set: function (value) {
            this.nativeInstance.d = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSDOMMatrix.prototype, "e", {
        get: function () {
            return this.nativeInstance.e;
        },
        set: function (value) {
            this.nativeInstance.e = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSDOMMatrix.prototype, "f", {
        get: function () {
            return this.nativeInstance.f;
        },
        set: function (value) {
            this.nativeInstance.f = value;
        },
        enumerable: true,
        configurable: true
    });
    return TNSDOMMatrix;
}(canvas_plugin_common_1.TNSDOMMatrixBase));
exports.TNSDOMMatrix = TNSDOMMatrix;
var CanvasGradient = (function (_super) {
    __extends(CanvasGradient, _super);
    function CanvasGradient(nativeInstance) {
        var _this = _super.call(this) || this;
        _this.nativeInstance = nativeInstance;
        return _this;
    }
    CanvasGradient.prototype.addColorStop = function (offset, color) {
        this.nativeInstance.addColorStopWithOffsetColor(offset, new color_1.Color(color).ios);
    };
    CanvasGradient.fromNative = function (nativeInstance) {
        return new CanvasGradient(nativeInstance);
    };
    Object.defineProperty(CanvasGradient.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return CanvasGradient;
}(canvas_plugin_common_1.CanvasGradientBase));
exports.CanvasGradient = CanvasGradient;
function requestAnimationFrame(loop) {
    return AnimationFrame.requestAnimationFrameToLoop(function (called) {
        loop(called);
    });
}
exports.requestAnimationFrame = requestAnimationFrame;
function cancelAnimationFrame(id) {
    AnimationFrame.cancelAnimationFrameWithId(id);
}
exports.cancelAnimationFrame = cancelAnimationFrame;
//# sourceMappingURL=canvas-plugin.ios.js.map